.. _installation:

Installation
============

Add instructions on how to install pysmatch here. You can include content from your README.

.. code-block:: bash

   pip install pysmatch

Or install from source:

.. code-block:: bash

   git clone https://github.com/miaohancheng/pysmatch.git
   cd pysmatch
   pip install .

Dependencies
------------
* Python 3.x
* pandas
* numpy
* scipy
* statsmodels
* scikit-learn
* matplotlib
* catboost
* optuna
* imbalanced-learn
* seaborn
